# Changelog
All notable changes to this project will be documented in this file.


## [0.1.1] - 2022-03-23

### Added
- *Emulation*
    - Added `PathAddBackslash` SHLWAPI hook

### Fixed
- *Emulation*
  - Mask off any CSIDL flags before resolving folder in `SHGetFolderPath`
- Fixed failure of tests due to ordering.


## 0.1.0 - 2022-02-04
- Initial release.
- Migrated the majority of Kordesii functionality to work with Dragodis.


[Unreleased]: https://github.com/Defense-Cyber-Crime-Center/rugosa/compare/0.1.1...HEAD
[0.1.1]: https://github.com/Defense-Cyber-Crime-Center/rugosa/compare/0.1.0...0.1.1
